#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define app_name erlware_commons
%define app_ver %(echo "%{version}" | cut -d "+" -f1)
Name:           erlang-%{app_name}
Version:        1.6.0
Release:        3.2
Summary:        A project focused on all aspects of reusable Erlang components
License:        Apache-2.0 AND MIT
Group:          Development/Libraries/Other
URL:            https://github.com/erlware/erlware_commons
Source:         %{app_name}-%{version}.tar.xz
BuildRequires:  erlang >= 26
BuildRequires:  erlang-cf
BuildRequires:  erlang-rebar
# make the tests happy
BuildRequires:  git
Requires:       erlang >= 26
Requires:       erlang-cf

%description
Erlware Commons is an Erlware project focused on all aspects of reusable Erlang components.

%prep
%setup -q -n %{app_name}-%{version}

%build
%rebar compile

%install
for dir in ebin include priv ; do
	mkdir -p %{buildroot}%{erlang_libdir}/%{app_name}-%{app_ver}/${dir}
	cp -r ${dir}/* %{buildroot}%{erlang_libdir}/%{app_name}-%{app_ver}/${dir}/
done

%check
# ec_cmd_log:color_test is expecting that erlang-cf package considers the TERMinal
# as color-capable one.
export TERM=ansi
%rebar eunit

%files
%license COPYING
%doc doc
%dir %{erlang_libdir}/%{app_name}-%{app_ver}
%dir %{erlang_libdir}/%{app_name}-%{app_ver}/ebin
%{erlang_libdir}/%{app_name}-%{app_ver}/ebin/%{app_name}.app
%{erlang_libdir}/%{app_name}-%{app_ver}/ebin/*.beam
%dir %{erlang_libdir}/%{app_name}-%{app_ver}/include
%{erlang_libdir}/%{app_name}-%{app_ver}/include/*.hrl
%{erlang_libdir}/%{app_name}-%{app_ver}/priv

%changelog
* Wed May 22 2024 Simon Lees <sflees@suse.de>
- We use a linked copy of this package in some SUSE products and
  to do so correctly, we need to ensure a minimum of erlang 26
  Leap will soon get a versioned copy of erlang26 as well
* Tue Sep 19 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correct license to Apache 2.0 and MIT
  This project contains elements licensed with Apache License, Version 2.0,
  as well as elements licensed with The MIT License.
* Sun Feb 26 2023 dmueller@suse.com
- use disabled services to be compatible with factory policy
* Thu Mar 31 2022 mvetter@suse.com
- Update to version 1.6.0:
  * Support Unicode string formatting
  * Tweak CI versions (add 24.0, move 23.2 to 23.3)
  * Keep symlinks in copies
  * Improve on license-related information
  * Solve dialyzer warnings while approaching expected behaviour
  * gitignore test-generated elements
  * Have CI working with extra checks
  * Remove dead code
* Sat Jan 16 2021 Matwey Kornilov <matwey.kornilov@gmail.com>
- Fix running unit test
* Wed Jan 13 2021 matwey.kornilov@gmail.com
- Update to version 1.4.0:
  * set TERM os var to xterm to get cf to not drop color in logs
  * update readme status badge and CI branch
  * move to github actions for CI
  * Better comment wording as suggested by @ferd
  * Avoid a warning on Erlang/OTP 24
  * Replace ericbmerritt links in README
  * Fix spelling/grammar in signatures.md
  * Allow for extra hyphens in pre-release build version
  * fix ec_semver:pes test to not ignore alpha versions
* Tue Jun 17 2014 matwey.kornilov@gmail.com
- Fix build for 17.0
* Wed Apr 16 2014 matwey.kornilov@gmail.com
- Version 0.11.0
* Mon Apr 29 2013 nkrinner@suse.com
- Initial package
